Crate autapi

Crate autapi 

Re-exports

pub use axum;
pub use http;

Modules

adapters
Adapters for bridging between the traits in this crate and traits in axum and serde
endpoint
Request handlers with OpenAPI description
openapi
Implementation of the OpenAPI specification
request
Extraction from and description of requests
response
Conversion to and description of responses
schema
JSON Schema for Rust types

Macros

info_from_env

Structs

NestedRouter
Configure endpoints for a router starting with a path.
Registry
Keeps track of components during schema generation.
Router
Wrapper around axum’s Router, allowing registration of endpoints.
Undocumented
General-purpose wrapper for things that should not be added to the API description.
UndocumentedAxum
General-purpose wrapper for types that implement axum’s traits and should be used with this crate, but without modifying the API description.