Module schema

Module schema 

JSON Schema for Rust types

Structs

IteratorArray
Implements SchemaSerialize for an iterator by serializing the elements into a sequence.
IteratorMap
Implements SchemaSerialize for an iterator by serializing the key/value-pairs into a map.
Nullable
A field that may be null.

Traits

IteratorItemMapper
SchemaDeserialize
A type that is deserializable according to its schema specification.
SchemaSerialize
A type that is serializable according to its schema specification.
SchemaUsing
Allows serializing or deserializing a type using another compatible one.
ToSchema
A type that is described with a Schema.

Type Aliases

BoxedIteratorArray
BoxedIteratorMap
MappedSliceIteratorArray
SliceIteratorArray

Derive Macros

ToSchema
Implement ToSchema, SchemaSerialize and SchemaDeserialize for a type.