IteratorArray

Struct IteratorArray 

pub struct IteratorArray<'i, I, M = ()>(/* private fields */);
Implements SchemaSerialize for an iterator by serializing the elements into a sequence.

A value of this type should only be serialized one. Serializing multiple times will result in an error.

Implementations

Source

impl<I> IteratorArray<'_, I>

pub fn new(iter: I) -> Self

Source

impl<I, M> IteratorArray<'_, I, M>

pub fn with_mapper(iter: I, mapper: M) -> Self

Source

impl<'i, T> IteratorArray<'i, Box<dyn Iterator<Item = T> + 'i>>

pub fn boxed(iter: impl IntoIterator<Item = T> + 'i) -> Self

Source

impl<'a, Mapped, T> IteratorArray<'a, Map<Iter<'a, T>, fn(&'a T) -> Mapped>>

pub fn map_slice(slice: &'a [T], map: fn(&'a T) -> Mapped) -> Self

Source

impl<'a, T> IteratorArray<'a, Iter<'a, T>>

pub fn slice(slice: &'a [T]) -> Self