JSON Schema for Rust types
Structs
- Iterator
Array - Implements
SchemaSerializefor an iterator by serializing the elements into a sequence. - Iterator
Map - Implements
SchemaSerializefor an iterator by serializing the key/value-pairs into a map. - Nullable
- A field that may be null.
Traits
- Iterator
Item Mapper - Schema
Deserialize - A type that is deserializable according to its schema specification.
- Schema
Serialize - A type that is serializable according to its schema specification.
- Schema
Using - Allows serializing or deserializing a type using another compatible one.
- ToSchema
- A type that is described with a
Schema.
Type Aliases
Derive Macros
- ToSchema
- Implement
ToSchema,SchemaSerializeandSchemaDeserializefor a type.