pub struct IteratorArray<'i, I, M = ()>(/* private fields */);Expand description
Implements SchemaSerialize for an iterator by serializing the elements into a sequence.
A value of this type should only be serialized one. Serializing multiple times will result in an error.
Implementations
Sourceimpl<I> IteratorArray<'_, I>
impl<I> IteratorArray<'_, I>
Sourceimpl<I, M> IteratorArray<'_, I, M>
impl<I, M> IteratorArray<'_, I, M>
pub fn with_mapper(iter: I, mapper: M) -> Self
Sourceimpl<'i, T> IteratorArray<'i, Box<dyn Iterator<Item = T> + 'i>>
impl<'i, T> IteratorArray<'i, Box<dyn Iterator<Item = T> + 'i>>
pub fn boxed(iter: impl IntoIterator<Item = T> + 'i) -> Self